km3pipe.dataclasses.HitSeries
=============================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: HitSeries

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HitSeries.__init__
      ~HitSeries.deserialise
      ~HitSeries.from_aanet
      ~HitSeries.from_arrays
      ~HitSeries.from_dict
      ~HitSeries.from_evt
      ~HitSeries.from_table
      ~HitSeries.next
      ~HitSeries.serialise
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HitSeries.channel_id
      ~HitSeries.dir_x
      ~HitSeries.dir_y
      ~HitSeries.dir_z
      ~HitSeries.dom_id
      ~HitSeries.dtype
      ~HitSeries.id
      ~HitSeries.pmt_id
      ~HitSeries.pos_x
      ~HitSeries.pos_y
      ~HitSeries.pos_z
      ~HitSeries.t0
      ~HitSeries.time
      ~HitSeries.tot
      ~HitSeries.triggered
      ~HitSeries.triggered_hits
   
   